verboselogs documentation
=========================

Welcome to the documentation of `verboselogs` version |release|!

The first part of the documentation is the readme which gives you a general
overview of the `verboselogs` package:

.. toctree::
   readme

The second part is the documentation of the available modules:

.. toctree::
   api
